==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_MapPoint.pm <==
package WebGUI::i18n::Spanish::Asset_MapPoint;
use utf8;
our $I18N = {
  'address1' => {
    'lastUpdated' => '1272375381',
    'message' => 'La primera línea de la dirección.'
  },
  'address1 description' => {
    'lastUpdated' => '1253292604',
    'message' => 'Primera línea de la dirección'
  },
  'address1 label' => {
    'lastUpdated' => '1253292661',
    'message' => 'Dirección 1'
  },
  'address2' => {
    'lastUpdated' => '1272375389',
    'message' => 'La segunda línea de la dirección.'
  },
  'address2 description' => {
    'lastUpdated' => '1253292631',
    'message' => 'Segunda línea de la dirección'
  },
  'address2 label' => {
    'lastUpdated' => '1253292652',
    'message' => 'Dirección 2'
  },
  'address3' => {
    'lastUpdated' => '1272375398',
    'message' => 'La tercera línea de la dirección.'
  },
  'assetName' => {
    'lastUpdated' => '1253292677',
    'message' => 'Punto en Mapa'
  },
  'city' => {
    'lastUpdated' => '1272375421',
    'message' => 'La ciudad para este Punto.'
  },
  'city description' => {
    'lastUpdated' => '1253292690',
    'message' => 'La ciudad en la cual se encuentra el Punto.'
  },
  'city label' => {
    'lastUpdated' => '1253292695',
    'message' => 'Ciudad'
  },
  'country' => {
    'lastUpdated' => '1272375429',
    'message' => 'El país para este Punto.'
  },
  'country description' => {
    'lastUpdated' => '1253292707',
    'message' => 'El país en el cual se encuentra el Punto.'
  },
  'country label' => {
    'lastUpdated' => '1253292713',
    'message' => 'País'
  },
  'currentPhoto' => {
    'lastUpdated' => '1272375451',
    'message' => 'Una marca img que enlaza con cualquier foto disponible.'
  },
  'edit template' => {
    'lastUpdated' => '1272375461',
    'message' => 'Plantilla para Editar Punto en Mapa'
  },
  'email' => {
    'lastUpdated' => '1272375475',
    'message' => 'La dirección de correo asociada a este Punto.'
  },
  'email description' => {
    'lastUpdated' => '1253292730',
    'message' => 'La dirección de correo electrónico asociada al Punto.'
  },
  'email label' => {
    'lastUpdated' => '1253292738',
    'message' => 'Correo Electrónico'
  },
  'fax' => {
    'lastUpdated' => '1272375485',
    'message' => 'El número de fax asociado a este Punto.'
  },
  'fax description' => {
    'lastUpdated' => '1253292748',
    'message' => 'El número de fax asociado al Punto.'
  },
  'fax label' => {
    'lastUpdated' => '1253292753',
    'message' => 'Fax'
  },
  'form_address1' => {
    'lastUpdated' => '1272375502',
    'message' => 'Un campo de texto para ingresar una parte de la dirección.'
  },
  'form_address2' => {
    'lastUpdated' => '1272375510',
    'message' => 'Un campo de texto para ingresar otra parte de la dirección.'
  },
  'form_address3' => {
    'lastUpdated' => '1272375519',
    'message' => 'Un campo de texto para ingresar la última parte de la dirección.'
  },
  'form_city' => {
    'lastUpdated' => '1272375531',
    'message' => 'Un campo de texto para ingresar la ciudad.'
  },
  'form_country' => {
    'lastUpdated' => '1272375541',
    'message' => 'Un campo de texto para ingresar el país.'
  },
  'form_email' => {
    'lastUpdated' => '1272375552',
    'message' => 'Un campo de texto para ingresar la dirección de correo.'
  },
  'form_fax' => {
    'lastUpdated' => '1272375562',
    'message' => 'Un campo de texto para ingresar el número de fax.'
  },
  'form_footer' => {
    'lastUpdated' => '1272375580',
    'message' => 'Fragmento HTML para terminar el formulario de edición.'
  },
  'form_header' => {
    'lastUpdated' => '1272375593',
    'message' => 'Fragmento HTML para comenzar el formulario de edición.'
  },
  'form_phone' => {
    'lastUpdated' => '1272375605',
    'message' => 'Un campo de texto para ingresar el número de teléfono.'
  },
  'form_region' => {
    'lastUpdated' => '1272375619',
    'message' => 'Un campo de texto para ingresar la región, provincia o estado.'
  },
  'form_storageIdPhoto' => {
    'lastUpdated' => '1272375639',
    'message' => 'Un elemento de exploración de archivos para incorporar una foto relacionada con el Punto.'
  },
  'form_submit' => {
    'lastUpdated' => '1272375649',
    'message' => 'El botón para enviar el formulario.'
  },
  'form_synopsis' => {
    'lastUpdated' => '1272375669',
    'message' => 'Un área de texto para ingresar el resumen sinóptico.'
  },
  'form_title' => {
    'lastUpdated' => '1272375681',
    'message' => 'Un campo de texto para ingresar el título.'
  },
  'form_website' => {
    'lastUpdated' => '1272375690',
    'message' => 'Un campo de texto para ingresar el URL asociado.'
  },
  'form_zipCode' => {
    'lastUpdated' => '1272375699',
    'message' => 'Un campo de texto para ingresar el código postal.'
  },
  'latitude' => {
    'lastUpdated' => '1272375709',
    'message' => 'Latitud del Punto'
  },
  'latitude description' => {
    'lastUpdated' => '1272375765',
    'message' => 'La Latitud del Punto.'
  },
  'latitude label' => {
    'lastUpdated' => '1253292768',
    'message' => 'Latitud'
  },
  'longitude' => {
    'lastUpdated' => '1272375718',
    'message' => 'Longitud del Punto'
  },
  'longitude description' => {
    'lastUpdated' => '1253292776',
    'message' => 'La longitud del Punto.'
  },
  'longitude label' => {
    'lastUpdated' => '1253292784',
    'message' => 'Longitud'
  },
  'map point asset template variables' => {
    'lastUpdated' => '1272375778',
    'message' => 'Variables de Plantilla para Punto en Mapa'
  },
  'phone' => {
    'lastUpdated' => '1272375789',
    'message' => 'El número de teléfono asociado a este Punto.'
  },
  'phone description' => {
    'lastUpdated' => '1253292795',
    'message' => 'El número de teléfono asociado al Punto.'
  },
  'phone label' => {
    'lastUpdated' => '1253292802',
    'message' => 'Teléfono'
  },
  'region' => {
    'lastUpdated' => '1272375804',
    'message' => 'La región, provincia o estado del Punto.'
  },
  'state description' => {
    'lastUpdated' => '1253292816',
    'message' => 'El Estado/Provincia donde se encuentra el Punto.'
  },
  'state label' => {
    'lastUpdated' => '1253292823',
    'message' => 'Estado/Provincia'
  },
  'storageIdPhoto' => {
    'lastUpdated' => '1272375815',
    'message' => 'El identificador de almacenamiento para este Punto.'
  },
  'storageIdPhoto description' => {
    'lastUpdated' => '1253292835',
    'message' => 'Una foto asociada al Punto.'
  },
  'storageIdPhoto label' => {
    'lastUpdated' => '1253292843',
    'message' => 'Foto'
  },
  'website' => {
    'lastUpdated' => '1272375824',
    'message' => 'El sitio web asociado a este Punto.'
  },
  'website description' => {
    'lastUpdated' => '1253292947',
    'message' => 'Un URL para el sitio Web asociado al Sitio.'
  },
  'website label' => {
    'lastUpdated' => '1253292958',
    'message' => 'URL del Sitio'
  },
  'zipCode' => {
    'lastUpdated' => '1272375833',
    'message' => 'El código postal asociado a este Punto.'
  },
  'zipCode description' => {
    'lastUpdated' => '1253292980',
    'message' => 'ZIP/Código Postal asociado al Punto.'
  },
  'zipCode label' => {
    'lastUpdated' => '1253293161',
    'message' => 'ZIP/Código Postal'
  }
}
;

1;

==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_MapPoint.pm <==
package WebGUI::i18n::Spanish::Asset_MapPoint;
use utf8;
our $I18N = {
  'address1' => {
    'lastUpdated' => '1272375381',
    'message' => 'La primera línea de la dirección.'
  },
  'address1 description' => {
    'lastUpdated' => '1253292604',
    'message' => 'Primera línea de la dirección'
  },
  'address1 label' => {
    'lastUpdated' => '1253292661',
    'message' => 'Dirección 1'
  },
  'address2' => {
    'lastUpdated' => '1272375389',
    'message' => 'La segunda línea de la dirección.'
  },
  'address2 description' => {
    'lastUpdated' => '1253292631',
    'message' => 'Segunda línea de la dirección'
  },
  'address2 label' => {
    'lastUpdated' => '1253292652',
    'message' => 'Dirección 2'
  },
  'address3' => {
    'lastUpdated' => '1272375398',
    'message' => 'La tercera línea de la dirección.'
  },
  'assetName' => {
    'lastUpdated' => '1253292677',
    'message' => 'Punto en Mapa'
  },
  'city' => {
    'lastUpdated' => '1272375421',
    'message' => 'La ciudad para este Punto.'
  },
  'city description' => {
    'lastUpdated' => '1253292690',
    'message' => 'La ciudad en la cual se encuentra el Punto.'
  },
  'city label' => {
    'lastUpdated' => '1253292695',
    'message' => 'Ciudad'
  },
  'country' => {
    'lastUpdated' => '1272375429',
    'message' => 'El país para este Punto.'
  },
  'country description' => {
    'lastUpdated' => '1253292707',
    'message' => 'El país en el cual se encuentra el Punto.'
  },
  'country label' => {
    'lastUpdated' => '1253292713',
    'message' => 'País'
  },
  'currentPhoto' => {
    'lastUpdated' => '1272375451',
    'message' => 'Una marca img que enlaza con cualquier foto disponible.'
  },
  'edit template' => {
    'lastUpdated' => '1272375461',
    'message' => 'Plantilla para Editar Punto en Mapa'
  },
  'email' => {
    'lastUpdated' => '1272375475',
    'message' => 'La dirección de correo asociada a este Punto.'
  },
  'email description' => {
    'lastUpdated' => '1253292730',
    'message' => 'La dirección de correo electrónico asociada al Punto.'
  },
  'email label' => {
    'lastUpdated' => '1253292738',
    'message' => 'Correo Electrónico'
  },
  'fax' => {
    'lastUpdated' => '1272375485',
    'message' => 'El número de fax asociado a este Punto.'
  },
  'fax description' => {
    'lastUpdated' => '1253292748',
    'message' => 'El número de fax asociado al Punto.'
  },
  'fax label' => {
    'lastUpdated' => '1253292753',
    'message' => 'Fax'
  },
  'form_address1' => {
    'lastUpdated' => '1272375502',
    'message' => 'Un campo de texto para ingresar una parte de la dirección.'
  },
  'form_address2' => {
    'lastUpdated' => '1272375510',
    'message' => 'Un campo de texto para ingresar otra parte de la dirección.'
  },
  'form_address3' => {
    'lastUpdated' => '1272375519',
    'message' => 'Un campo de texto para ingresar la última parte de la dirección.'
  },
  'form_city' => {
    'lastUpdated' => '1272375531',
    'message' => 'Un campo de texto para ingresar la ciudad.'
  },
  'form_country' => {
    'lastUpdated' => '1272375541',
    'message' => 'Un campo de texto para ingresar el país.'
  },
  'form_email' => {
    'lastUpdated' => '1272375552',
    'message' => 'Un campo de texto para ingresar la dirección de correo.'
  },
  'form_fax' => {
    'lastUpdated' => '1272375562',
    'message' => 'Un campo de texto para ingresar el número de fax.'
  },
  'form_footer' => {
    'lastUpdated' => '1272375580',
    'message' => 'Fragmento HTML para terminar el formulario de edición.'
  },
  'form_header' => {
    'lastUpdated' => '1272375593',
    'message' => 'Fragmento HTML para comenzar el formulario de edición.'
  },
  'form_phone' => {
    'lastUpdated' => '1272375605',
    'message' => 'Un campo de texto para ingresar el número de teléfono.'
  },
  'form_region' => {
    'lastUpdated' => '1272375619',
    'message' => 'Un campo de texto para ingresar la región, provincia o estado.'
  },
  'form_storageIdPhoto' => {
    'lastUpdated' => '1272375639',
    'message' => 'Un elemento de exploración de archivos para incorporar una foto relacionada con el Punto.'
  },
  'form_submit' => {
    'lastUpdated' => '1272375649',
    'message' => 'El botón para enviar el formulario.'
  },
  'form_synopsis' => {
    'lastUpdated' => '1272375669',
    'message' => 'Un área de texto para ingresar el resumen sinóptico.'
  },
  'form_title' => {
    'lastUpdated' => '1272375681',
    'message' => 'Un campo de texto para ingresar el título.'
  },
  'form_website' => {
    'lastUpdated' => '1272375690',
    'message' => 'Un campo de texto para ingresar el URL asociado.'
  },
  'form_zipCode' => {
    'lastUpdated' => '1272375699',
    'message' => 'Un campo de texto para ingresar el código postal.'
  },
  'latitude' => {
    'lastUpdated' => '1272375709',
    'message' => 'Latitud del Punto'
  },
  'latitude description' => {
    'lastUpdated' => '1272375765',
    'message' => 'La Latitud del Punto.'
  },
  'latitude label' => {
    'lastUpdated' => '1253292768',
    'message' => 'Latitud'
  },
  'longitude' => {
    'lastUpdated' => '1272375718',
    'message' => 'Longitud del Punto'
  },
  'longitude description' => {
    'lastUpdated' => '1253292776',
    'message' => 'La longitud del Punto.'
  },
  'longitude label' => {
    'lastUpdated' => '1253292784',
    'message' => 'Longitud'
  },
  'map point asset template variables' => {
    'lastUpdated' => '1272375778',
    'message' => 'Variables de Plantilla para Punto en Mapa'
  },
  'phone' => {
    'lastUpdated' => '1272375789',
    'message' => 'El número de teléfono asociado a este Punto.'
  },
  'phone description' => {
    'lastUpdated' => '1253292795',
    'message' => 'El número de teléfono asociado al Punto.'
  },
  'phone label' => {
    'lastUpdated' => '1253292802',
    'message' => 'Teléfono'
  },
  'region' => {
    'lastUpdated' => '1272375804',
    'message' => 'La región, provincia o estado del Punto.'
  },
  'state description' => {
    'lastUpdated' => '1253292816',
    'message' => 'El Estado/Provincia donde se encuentra el Punto.'
  },
  'state label' => {
    'lastUpdated' => '1253292823',
    'message' => 'Estado/Provincia'
  },
  'storageIdPhoto' => {
    'lastUpdated' => '1272375815',
    'message' => 'El identificador de almacenamiento para este Punto.'
  },
  'storageIdPhoto description' => {
    'lastUpdated' => '1253292835',
    'message' => 'Una foto asociada al Punto.'
  },
  'storageIdPhoto label' => {
    'lastUpdated' => '1253292843',
    'message' => 'Foto'
  },
  'user defined variables' => {
    'lastUpdated' => '1302872821',
    'message' => 'A diferencia del Sistema de Colaboración, un Punto en Mapa no provee campos predefinidos para aquellas variables definidas por el usuario. Por el contrario, Ud. debe crear cualquier tipo de campo de formulario que sea necesario, incluyendo el nombre que WebGUI deberá utilizar para el campo cuando lo almacene.'
  },
  'userDefined1' => {
    'lastUpdated' => '1302872874',
    'message' => 'El valor del Campo 1 Definido por el Usuario.'
  },
  'userDefined2' => {
    'lastUpdated' => '1302872881',
    'message' => 'El valor del Campo 2 Definido por el Usuario.'
  },
  'userDefined3' => {
    'lastUpdated' => '1302872887',
    'message' => 'El valor del Campo 3 Definido por el Usuario.'
  },
  'userDefined4' => {
    'lastUpdated' => '1302872893',
    'message' => 'El valor del Campo 4 Definido por el Usuario.'
  },
  'userDefined5' => {
    'lastUpdated' => '1302872899',
    'message' => 'El valor del Campo 5 Definido por el Usuario.'
  },
  'website' => {
    'lastUpdated' => '1272375824',
    'message' => 'El sitio web asociado a este Punto.'
  },
  'website description' => {
    'lastUpdated' => '1253292947',
    'message' => 'Un URL para el sitio Web asociado al Sitio.'
  },
  'website label' => {
    'lastUpdated' => '1253292958',
    'message' => 'URL del Sitio'
  },
  'zipCode' => {
    'lastUpdated' => '1272375833',
    'message' => 'El código postal asociado a este Punto.'
  },
  'zipCode description' => {
    'lastUpdated' => '1253292980',
    'message' => 'ZIP/Código Postal asociado al Punto.'
  },
  'zipCode label' => {
    'lastUpdated' => '1253293161',
    'message' => 'ZIP/Código Postal'
  }
}
;

1;
